----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Joachim Schmidt <joachim.schmidt@hesge.ch>
--
-- Module Name: tb_scalp_matrix_index.vhd
-- Target Device: SCALP xc7z015clg485-2
-- Tool version: 2019.1
-- Description: Testbench for scalp_matrix_index
--
-- Last update: 2020-01-19
--
---------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

--use ieee.std_logic_unsigned.all;
--use ieee.std_logic_arith.all;
--use ieee.std_logic_misc.all;

--library UNISIM;
--use UNISIM.VCOMPONENTS.all;

library work;
use work.scalp_utility.all;

entity tb_scalp_matrix_index is

end entity tb_scalp_matrix_index;

architecture testbench of tb_scalp_matrix_index is

    constant C_SCALP_INTERFACE_VECTOR_SIZE : integer range 0 to 255 := 7;
    constant C_CLK_PERIOD                  : time                   := 10 ns;

    component scalp_matrix_index is
        generic (
            C_SCALP_INTERFACE_VECTOR_SIZE : integer range 0 to 255);
        port (
            IfSrcNumxDI      : in  integer range 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1);
            IfDstNumxDI      : in  integer range 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1);
            IfNumValidxSI    : in  std_ulogic;
            IfDstIdxxDO      : out integer range 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1);
            IfDstIdxValidxSO : out std_ulogic);
    end component scalp_matrix_index;

    signal IfSrcNumxD      : integer range 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1) := 0;
    signal IfDstNumxD      : integer range 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1) := 0;
    signal IfNumValidxS    : std_ulogic                                             := '0';
    signal IfDstIdxxD      : integer range 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1) := 0;
    signal IfDstIdxValidxS : std_ulogic                                             := '0';
    signal TestResultxD    : integer range 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1) := 0;

begin  -- architecture testbench    

    ScalpMatrixIndexxI : entity work.scalp_matrix_index
        generic map (
            C_SCALP_INTERFACE_VECTOR_SIZE => C_SCALP_INTERFACE_VECTOR_SIZE)
        port map (
            IfSrcNumxDI      => IfSrcNumxD,
            IfDstNumxDI      => IfDstNumxD,
            IfNumValidxSI    => IfNumValidxS,
            IfDstIdxxDO      => IfDstIdxxD,
            IfDstIdxValidxSO => IfDstIdxValidxS);

    AsyncStatementsxB : block is
    begin  -- block AsyncStatementsxB

        TestResultxAS : TestResultxD <= ((IfDstNumxD - (IfSrcNumxD + 1)) mod C_SCALP_INTERFACE_VECTOR_SIZE);

    end block AsyncStatementsxB;

    CheckScalpMatrixIndexxP : process is
    begin  -- process CheckScalpMatrixIndexxP

        report "Scalp Matrix Index checking is started" severity note;

        IfNumValidxS <= '1';

        for i in 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1) loop
            IfSrcNumxD <= i;
            for j in 0 to (C_SCALP_INTERFACE_VECTOR_SIZE - 1) loop
                IfDstNumxD <= j;

                wait for C_CLK_PERIOD;

                report "@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@" severity note;
                report "Iteration i = " & integer'image(i) & ", j = " & integer'image(j) severity note;
                report "@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@" severity note;

                if IfDstIdxValidxS = '0' then
                    report "++++++++++++++++++++++++++++++++++++++++" severity note;
                    report "IfDstIdxxD   = " & integer'image(IfDstIdxxD) severity note;
                    report "TestResultxD = " & integer'image(TestResultxD) severity note;
                    report "No mistake, the indefinite condition when i = j" severity note;
                    report "++++++++++++++++++++++++++++++++++++++++" severity note;
                else
                    report "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" severity note;
                    report "IfDstIdxxD   = " & integer'image(IfDstIdxxD) severity note;
                    report "TestResultxD = " & integer'image(TestResultxD) severity note;
                    assert IfDstIdxxD = TestResultxD report "Error : unexpected value at current iteration!" severity failure;
                    report "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" severity note;
                end if;
            end loop;  -- j
        end loop;  -- i

        IfNumValidxS <= '0';

        report "Scalp Matrix Index checking is finished" severity note;

        wait;
    end process CheckScalpMatrixIndexxP;

end architecture testbench;
