----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Joachim Schmidt <joachim.schmidt@hesge.ch>
--
-- Module Name: tb_scalp_router.vhd
-- Target Device: SCALP xc7z015clg485-2
-- Tool version: 2019.1
-- Description: Testbench for scalp_router (NoC).
--
-- Last update: 2020-11-30
--
---------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
use ieee.math_real.all;
-- use ieee.math_real.uniform;
-- use ieee.math_real.floor;

--use ieee.std_logic_unsigned.all;
--use ieee.std_logic_arith.all;
--use ieee.std_logic_misc.all;

--library UNISIM;
--use UNISIM.VCOMPONENTS.all;

library work;
use work.axi4_pkg.all;
use work.scalp_misc.all;
use work.scalp_utility.all;
use work.scalp_sim_packets.all;

entity tb_scalp_router is

end entity tb_scalp_router;

architecture testbench of tb_scalp_router is

    constant C_CLK_PERIOD                : time                   := 10 ns;
    constant C_SCALP_NUMBER_OF_INTERFACE : integer range 0 to 255 := 7;
    constant C_SCALP_SCHEDULER_STRATEGY  : string                 := "RR";
    -- constant C_SCALP_PACKET_PAYLOAD_SIZE : integer range 1 to C_SCALP_PACKET_LENGTH_RANGE_VALUE := 8;
    constant C_SCALP_RANDOM_READY        : boolean                := false;
    -- Interface de destination
    -- constant C_SCALP_DST_IF_ID           : integer range 0 to 6   := C_NORTH_IF_ID;

    component scalp_router is
        generic (
            C_SCALP_NUMBER_OF_INTERFACE : integer range 0 to 255;
            C_SCALP_SCHEDULER_STRATEGY  : string);
        port (
            -- System Clock and System nReset
            SysClkxCI          : in  std_ulogic;
            SysRstxRNAI        : in  std_ulogic;
            -- Local Router Network Address
            LocNetAddrxDI      : in  t_scalp_netaddr;
            -- Axi4 Stream
            -- RX Side Vector
            RXAxism2sVectorxDI : in  t_axi4m2s_vector((C_SCALP_NUMBER_OF_INTERFACE - 1) downto 0);
            RXAxiss2mVectorxDO : out t_axi4s2m_vector((C_SCALP_NUMBER_OF_INTERFACE - 1) downto 0);
            -- TX Side Vector
            TXAxism2sVectorxDO : out t_axi4m2s_vector((C_SCALP_NUMBER_OF_INTERFACE - 1) downto 0);
            TXAxiss2mVectorxDI : in  t_axi4s2m_vector((C_SCALP_NUMBER_OF_INTERFACE - 1) downto 0);
            -- QoS Vector
            QoSVectorxDI       : in  t_scalp_qos_vector((C_SCALP_NUMBER_OF_INTERFACE - 1) downto 0));
    end component scalp_router;

    component scalp_sp_to_axis is
        generic (
            C_SCALP_PACKET_PAYLOAD_SIZE : integer range 1 to C_SCALP_PACKET_LENGTH_RANGE_VALUE);
        port (
            SysClkxCI           : in  std_ulogic;
            SysRstxRNAI         : in  std_ulogic;
            ScalpPacketxDI      : in  t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1)));
            ScalpPacketValidxSI : in  std_ulogic;
            ScalpAxism2sxDO     : out t_axi4m2s;
            ScalpAxiss2mxDI     : in  t_axi4s2m;
            ScalpRdyxSO         : out std_ulogic);
    end component scalp_sp_to_axis;

    component scalp_axis_to_sp is
        generic (
            C_SCALP_PACKET_PAYLOAD_SIZE : integer range 1 to C_SCALP_PACKET_LENGTH_RANGE_VALUE;
            C_SCALP_RANDOM_READY        : boolean);
        port (
            SysClkxCI           : in  std_ulogic;
            SysRstxRNAI         : in  std_ulogic;
            ScalpAxism2sxDI     : in  t_axi4m2s;
            ScalpAxiss2mxDO     : out t_axi4s2m;
            ScalpPacketxDO      : out t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1)));
            ScalpPacketValidxSO : out std_ulogic);
    end component scalp_axis_to_sp;

    -- Sys Clk and Sys nRst
    signal SysClkxC           : std_ulogic                                                     := '0';
    signal SysRstxRNA         : std_ulogic                                                     := '0';
    -- End of Simulation
    signal EndSimxS           : boolean                                                        := false;
    signal ScalpDstIfIdxD     : integer range 0 to 6                                           := C_NORTH_IF_ID;
    signal ScalpRdyxD         : std_ulogic_vector((C_SCALP_NUMBER_OF_INTERFACE - 1) downto 0)  := (others => '0');
    -- Scalp Router
    signal LocNetAddrxD       : t_scalp_netaddr                                                := C_SCALP_NET_ADDR_111;
    signal RXAxism2sVectorxD  : t_axi4m2s_vector((C_SCALP_NUMBER_OF_INTERFACE - 1) downto 0)   := (others => C_NO_AXI4_M2S);
    signal RXAxiss2mVectorxD  : t_axi4s2m_vector((C_SCALP_NUMBER_OF_INTERFACE - 1) downto 0)   := (others => C_NO_AXI4_S2M);
    signal TXAxism2sVectorxD  : t_axi4m2s_vector((C_SCALP_NUMBER_OF_INTERFACE - 1) downto 0)   := (others => C_NO_AXI4_M2S);
    signal TXAxiss2mVectorxD  : t_axi4s2m_vector((C_SCALP_NUMBER_OF_INTERFACE - 1) downto 0)   := (others => C_NO_AXI4_S2M);
    signal QoSVectorxD        : t_scalp_qos_vector((C_SCALP_NUMBER_OF_INTERFACE - 1) downto 0) := (others => (others => '0'));
    -- Scalp Packet
    -- Start
    -- signal ScalpNorthEndCounterxD  : integer                                                        := 0;
    -- signal ScalpEastEndCounterxD   : integer                                                        := 0;
    -- signal ScalpSouthEndCounterxD  : integer                                                        := 0;
    -- signal ScalpWestEndCounterxD   : integer                                                        := 0;
    -- signal ScalpTopEndCounterxD    : integer                                                        := 0;
    -- signal ScalpBottomEndCounterxD : integer                                                        := 0;
    -- signal ScalpLocalEndCounterxD  : integer                                                        := 0;
    signal ScalpNorthIfEndxS  : std_ulogic                                                     := '0';
    signal ScalpEastIfEndxS   : std_ulogic                                                     := '0';
    signal ScalpSouthIfEndxS  : std_ulogic                                                     := '0';
    signal ScalpWestIfEndxS   : std_ulogic                                                     := '0';
    signal ScalpTopIfEndxS    : std_ulogic                                                     := '0';
    signal ScalpBottomIfEndxS : std_ulogic                                                     := '0';
    signal ScalpLocalIfEndxS  : std_ulogic                                                     := '0';
    -- Packet NULL
    signal ScalpPacketNullxD  : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_NULL,
         SpPayloadxD => C_SP_PAYLOAD_NULL);
    -- From North 121
    ---------------------------------------------------------------------------
    ---------------------------------------------------------------------------
    signal ScalpPacketNorthxD : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_NULL,
         SpPayloadxD => C_SP_PAYLOAD_NULL);
    signal ScalpPacketValidNorthxS  : std_ulogic := '0';
    signal ScalpPacketSelectNorthxD : integer    := 0;
    ---------------------------------------------------------------------------
    -- Packet 0
    signal ScalpPacket0xD           : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_121_TO_211,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid0xS : std_ulogic := '0';
    -- Packet 1
    signal ScalpPacket1xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_121_TO_101,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid1xS : std_ulogic := '0';
    -- Packet 2
    signal ScalpPacket2xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_121_TO_011,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid2xS : std_ulogic := '0';
    -- Packet 3
    signal ScalpPacket3xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_121_TO_112,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid3xS : std_ulogic := '0';
    -- Packet 4
    signal ScalpPacket4xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_121_TO_110,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid4xS : std_ulogic := '0';
    -- Packet 5
    signal ScalpPacket5xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_121_TO_111,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid5xS : std_ulogic := '0';
    -- From East 211
    ---------------------------------------------------------------------------
    ---------------------------------------------------------------------------
    signal ScalpPacketEastxD   : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_NULL,
         SpPayloadxD => C_SP_PAYLOAD_NULL);
    signal ScalpPacketValidEastxS  : std_ulogic := '0';
    signal ScalpPacketSelectEastxD : integer    := 0;
    ---------------------------------------------------------------------------
    -- Packet 6
    signal ScalpPacket6xD          : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_211_TO_121,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid6xS : std_ulogic := '0';
    -- Packet 7
    signal ScalpPacket7xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_211_TO_101,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid7xS : std_ulogic := '0';
    -- Packet 8
    signal ScalpPacket8xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_211_TO_011,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid8xS : std_ulogic := '0';
    -- Packet 9
    signal ScalpPacket9xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_211_TO_112,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid9xS : std_ulogic := '0';
    -- Packet 10
    signal ScalpPacket10xD     : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_211_TO_110,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid10xS : std_ulogic := '0';
    -- Packet 11
    signal ScalpPacket11xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_211_TO_111,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid11xS : std_ulogic := '0';
    -- From South 101
    ---------------------------------------------------------------------------
    ---------------------------------------------------------------------------
    signal ScalpPacketSouthxD   : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_NULL,
         SpPayloadxD => C_SP_PAYLOAD_NULL);
    signal ScalpPacketValidSouthxS  : std_ulogic := '0';
    signal ScalpPacketSelectSouthxD : integer    := 0;
    ---------------------------------------------------------------------------
    -- Packet 12
    signal ScalpPacket12xD          : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_101_TO_121,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid12xS : std_ulogic := '0';
    -- Packet 13
    signal ScalpPacket13xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_101_TO_211,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid13xS : std_ulogic := '0';
    -- Packet 14
    signal ScalpPacket14xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_101_TO_011,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid14xS : std_ulogic := '0';
    -- Packet 15
    signal ScalpPacket15xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_101_TO_112,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid15xS : std_ulogic := '0';
    -- Packet 16
    signal ScalpPacket16xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_101_TO_110,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid16xS : std_ulogic := '0';
    -- Packet 17
    signal ScalpPacket17xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_101_TO_111,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid17xS : std_ulogic := '0';
    -- From West 011
    ---------------------------------------------------------------------------
    ---------------------------------------------------------------------------
    signal ScalpPacketWestxD    : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_NULL,
         SpPayloadxD => C_SP_PAYLOAD_NULL);
    signal ScalpPacketValidWestxS  : std_ulogic := '0';
    signal ScalpPacketSelectWestxD : integer    := 0;
    ---------------------------------------------------------------------------
    -- Packet 18
    signal ScalpPacket18xD         : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_011_TO_121,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid18xS : std_ulogic := '0';
    -- Packet 19
    signal ScalpPacket19xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_011_TO_211,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid19xS : std_ulogic := '0';
    -- Packet 20
    signal ScalpPacket20xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_011_TO_101,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid20xS : std_ulogic := '0';
    -- Packet 21
    signal ScalpPacket21xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_011_TO_112,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid21xS : std_ulogic := '0';
    -- Packet 22
    signal ScalpPacket22xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_011_TO_110,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid22xS : std_ulogic := '0';
    -- Packet 23
    signal ScalpPacket23xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_011_TO_111,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid23xS : std_ulogic := '0';
    -- From Top 112
    ---------------------------------------------------------------------------
    ---------------------------------------------------------------------------
    signal ScalpPacketTopxD     : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_NULL,
         SpPayloadxD => C_SP_PAYLOAD_NULL);
    signal ScalpPacketValidTopxS  : std_ulogic := '0';
    signal ScalpPacketSelectTopxD : integer    := 0;
    ---------------------------------------------------------------------------
    -- Packet 24
    signal ScalpPacket24xD        : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_112_TO_121,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid24xS : std_ulogic := '0';
    -- Packet 25
    signal ScalpPacket25xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_112_TO_211,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid25xS : std_ulogic := '0';
    -- Packet 26
    signal ScalpPacket26xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_112_TO_101,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid26xS : std_ulogic := '0';
    -- Packet 27
    signal ScalpPacket27xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_112_TO_011,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid27xS : std_ulogic := '0';
    -- Packet 28
    signal ScalpPacket28xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_112_TO_110,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid28xS : std_ulogic := '0';
    -- Packet 29
    signal ScalpPacket29xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_112_TO_111,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid29xS : std_ulogic := '0';
    -- From Bottom 110
    ---------------------------------------------------------------------------
    ---------------------------------------------------------------------------
    signal ScalpPacketBottomxD  : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_NULL,
         SpPayloadxD => C_SP_PAYLOAD_NULL);
    signal ScalpPacketValidBottomxS  : std_ulogic := '0';
    signal ScalpPacketSelectBottomxD : integer    := 0;
    ---------------------------------------------------------------------------
    -- Packet 30
    signal ScalpPacket30xD           : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_110_TO_121,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid30xS : std_ulogic := '0';
    -- Packet 31
    signal ScalpPacket31xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_110_TO_211,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid31xS : std_ulogic := '0';
    -- Packet 32
    signal ScalpPacket32xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_110_TO_101,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid32xS : std_ulogic := '0';
    -- Packet 33
    signal ScalpPacket33xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_110_TO_011,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid33xS : std_ulogic := '0';
    -- Packet 34
    signal ScalpPacket34xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_110_TO_112,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid34xS : std_ulogic := '0';
    -- Packet 35
    signal ScalpPacket35xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_110_TO_111,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid35xS : std_ulogic := '0';
    -- From Local 111
    ---------------------------------------------------------------------------
    ---------------------------------------------------------------------------
    signal ScalpPacketLocalxD   : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_NULL,
         SpPayloadxD => C_SP_PAYLOAD_NULL);
    signal ScalpPacketValidLocalxS  : std_ulogic := '0';
    signal ScalpPacketSelectLocalxD : integer    := 0;
    ---------------------------------------------------------------------------
    -- Packet 36
    signal ScalpPacket36xD          : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_111_TO_121,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid36xS : std_ulogic := '0';
    -- Packet 37
    signal ScalpPacket37xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_111_TO_211,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid37xS : std_ulogic := '0';
    -- Packet 38
    signal ScalpPacket38xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_111_TO_101,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid38xS : std_ulogic := '0';
    -- Packet 39
    signal ScalpPacket39xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_111_TO_011,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid39xS : std_ulogic := '0';
    -- Packet 40
    signal ScalpPacket40xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_111_TO_112,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid40xS : std_ulogic := '0';
    -- Packet 41
    signal ScalpPacket41xD      : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_SP_HEADER_111_TO_110,
         SpPayloadxD => C_SP_PAYLOAD_0);
    signal ScalpPacketValid41xS  : std_ulogic := '0';
    -- End Packet
    ---------------------------------------------------------------------------
    signal ScalpPacketEndNorthxD : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_NO_SCALP_PACKET_HEADER,
         SpPayloadxD => (others => C_NO_SCALP_PACKET_WORD));
    signal ScalpPacketEndEastxD : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_NO_SCALP_PACKET_HEADER,
         SpPayloadxD => (others => C_NO_SCALP_PACKET_WORD));
    signal ScalpPacketEndSouthxD : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_NO_SCALP_PACKET_HEADER,
         SpPayloadxD => (others => C_NO_SCALP_PACKET_WORD));
    signal ScalpPacketEndWestxD : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_NO_SCALP_PACKET_HEADER,
         SpPayloadxD => (others => C_NO_SCALP_PACKET_WORD));
    signal ScalpPacketEndTopxD : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_NO_SCALP_PACKET_HEADER,
         SpPayloadxD => (others => C_NO_SCALP_PACKET_WORD));
    signal ScalpPacketEndBottomxD : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_NO_SCALP_PACKET_HEADER,
         SpPayloadxD => (others => C_NO_SCALP_PACKET_WORD));
    signal ScalpPacketEndLocalxD : t_scalp_packet(SpPayloadxD(0 to (C_SCALP_PACKET_PAYLOAD_SIZE - 1))) :=
        (SpHeaderxD  => C_NO_SCALP_PACKET_HEADER,
         SpPayloadxD => (others => C_NO_SCALP_PACKET_WORD));
    signal ScalpPacketValidEndxD : std_ulogic_vector((C_SCALP_NUMBER_OF_INTERFACE - 1) downto 0) := (others => '0');

    ---------------------------------------------------------------------------
    -- Variables
    ---------------------------------------------------------------------------
    shared variable ScalpNorthEndCounterxD  : integer := 0;
    shared variable ScalpEastEndCounterxD   : integer := 0;
    shared variable ScalpSouthEndCounterxD  : integer := 0;
    shared variable ScalpWestEndCounterxD   : integer := 0;
    shared variable ScalpTopEndCounterxD    : integer := 0;
    shared variable ScalpBottomEndCounterxD : integer := 0;
    shared variable ScalpLocalEndCounterxD  : integer := 0;

begin  -- architecture testbench

    AsyncStatementsxB : block is
    begin  -- block AsyncStatementsxB

        SysClkxAS : SysClkxC   <= not SysClkxC after (C_CLK_PERIOD / 2);
        SysRstxAS : SysRstxRNA <= '1'          after (C_CLK_PERIOD * 10);

    end block AsyncStatementsxB;

    EndSimxP : process is
    begin  -- process EndSimxP
        if EndSimxS = true then
            assert false report "End of simulation!" severity failure;
        end if;

        wait until rising_edge(SysClkxC);
    end process EndSimxP;

    ScalpSpToAxisNorthxI : entity work.scalp_sp_to_axis
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpPacketxDI      => ScalpPacketNorthxD,
            ScalpPacketValidxSI => ScalpPacketValidNorthxS,
            ScalpAxism2sxDO     => RXAxism2sVectorxD(C_NORTH_IF_ID),
            ScalpAxiss2mxDI     => RXAxiss2mVectorxD(C_NORTH_IF_ID),
            ScalpRdyxSO         => ScalpRdyxD(C_NORTH_IF_ID));

    ScalpSpToAxisEastxI : entity work.scalp_sp_to_axis
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpPacketxDI      => ScalpPacketEastxD,
            ScalpPacketValidxSI => ScalpPacketValidEastxS,
            ScalpAxism2sxDO     => RXAxism2sVectorxD(C_EAST_IF_ID),
            ScalpAxiss2mxDI     => RXAxiss2mVectorxD(C_EAST_IF_ID),
            ScalpRdyxSO         => ScalpRdyxD(C_EAST_IF_ID));

    ScalpSpToAxisSouthxI : entity work.scalp_sp_to_axis
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpPacketxDI      => ScalpPacketSouthxD,
            ScalpPacketValidxSI => ScalpPacketValidSouthxS,
            ScalpAxism2sxDO     => RXAxism2sVectorxD(C_SOUTH_IF_ID),
            ScalpAxiss2mxDI     => RXAxiss2mVectorxD(C_SOUTH_IF_ID),
            ScalpRdyxSO         => ScalpRdyxD(C_SOUTH_IF_ID));

    ScalpSpToAxisWestxI : entity work.scalp_sp_to_axis
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpPacketxDI      => ScalpPacketWestxD,
            ScalpPacketValidxSI => ScalpPacketValidWestxS,
            ScalpAxism2sxDO     => RXAxism2sVectorxD(C_WEST_IF_ID),
            ScalpAxiss2mxDI     => RXAxiss2mVectorxD(C_WEST_IF_ID),
            ScalpRdyxSO         => ScalpRdyxD(C_WEST_IF_ID));

    ScalpSpToAxisTopxI : entity work.scalp_sp_to_axis
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpPacketxDI      => ScalpPacketTopxD,
            ScalpPacketValidxSI => ScalpPacketValidTopxS,
            ScalpAxism2sxDO     => RXAxism2sVectorxD(C_TOP_IF_ID),
            ScalpAxiss2mxDI     => RXAxiss2mVectorxD(C_TOP_IF_ID),
            ScalpRdyxSO         => ScalpRdyxD(C_TOP_IF_ID));

    ScalpSpToAxisBottomxI : entity work.scalp_sp_to_axis
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpPacketxDI      => ScalpPacketBottomxD,
            ScalpPacketValidxSI => ScalpPacketValidBottomxS,
            ScalpAxism2sxDO     => RXAxism2sVectorxD(C_BOTTOM_IF_ID),
            ScalpAxiss2mxDI     => RXAxiss2mVectorxD(C_BOTTOM_IF_ID),
            ScalpRdyxSO         => ScalpRdyxD(C_BOTTOM_IF_ID));

    ScalpSpToAxisLocalxI : entity work.scalp_sp_to_axis
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpPacketxDI      => ScalpPacketLocalxD,
            ScalpPacketValidxSI => ScalpPacketValidLocalxS,
            ScalpAxism2sxDO     => RXAxism2sVectorxD(C_LOCAL_IF_ID),
            ScalpAxiss2mxDI     => RXAxiss2mVectorxD(C_LOCAL_IF_ID),
            ScalpRdyxSO         => ScalpRdyxD(C_LOCAL_IF_ID));

    ---------------------------------------------------------------------------
    -- ---------    ---------
    -- | 1 3 0 |    | 2 3 0 |
    -- ---------    ---------
    --                  S
    --                  N
    -- ---------    ---------
    -- | 1 2 0 |    | 2 2 0 |
    -- ---------    ---------
    --                  S
    --                  N
    -- ---------    ---------
    -- | 1 1 0 |E  W| 2 1 0 |  <---
    -- ---------    ---------

    ScalpRouterxI : entity work.scalp_router
        generic map (
            C_SCALP_NUMBER_OF_INTERFACE => C_SCALP_NUMBER_OF_INTERFACE,
            C_SCALP_SCHEDULER_STRATEGY  => C_SCALP_SCHEDULER_STRATEGY)
        port map (
            -- System Clock and System nReset
            SysClkxCI          => SysClkxC,
            SysRstxRNAI        => SysRstxRNA,
            -- Local Router Network Address
            LocNetAddrxDI      => LocNetAddrxD,
            -- Axi4 Stream
            -- RX Side Vector
            RXAxism2sVectorxDI => RXAxism2sVectorxD,
            RXAxiss2mVectorxDO => RXAxiss2mVectorxD,
            -- TX Side Vector
            TXAxism2sVectorxDO => TXAxism2sVectorxD,
            TXAxiss2mVectorxDI => TXAxiss2mVectorxD,
            -- QoS Vector
            QoSVectorxDI       => QoSVectorxD);

    ScalpAxisToSpNorthxI : entity work.scalp_axis_to_sp
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE,
            C_SCALP_RANDOM_READY        => C_SCALP_RANDOM_READY)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpAxism2sxDI     => TXAxism2sVectorxD(C_NORTH_IF_ID),
            ScalpAxiss2mxDO     => TXAxiss2mVectorxD(C_NORTH_IF_ID),
            ScalpPacketxDO      => ScalpPacketEndNorthxD,
            ScalpPacketValidxSO => ScalpPacketValidEndxD(C_NORTH_IF_ID));

    ScalpAxisToSpEastxI : entity work.scalp_axis_to_sp
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE,
            C_SCALP_RANDOM_READY        => C_SCALP_RANDOM_READY)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpAxism2sxDI     => TXAxism2sVectorxD(C_EAST_IF_ID),
            ScalpAxiss2mxDO     => TXAxiss2mVectorxD(C_EAST_IF_ID),
            ScalpPacketxDO      => ScalpPacketEndEastxD,
            ScalpPacketValidxSO => ScalpPacketValidEndxD(C_EAST_IF_ID));

    ScalpAxisToSpSouthxI : entity work.scalp_axis_to_sp
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE,
            C_SCALP_RANDOM_READY        => C_SCALP_RANDOM_READY)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpAxism2sxDI     => TXAxism2sVectorxD(C_SOUTH_IF_ID),
            ScalpAxiss2mxDO     => TXAxiss2mVectorxD(C_SOUTH_IF_ID),
            ScalpPacketxDO      => ScalpPacketEndSouthxD,
            ScalpPacketValidxSO => ScalpPacketValidEndxD(C_SOUTH_IF_ID));

    ScalpAxisToSpWestxI : entity work.scalp_axis_to_sp
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE,
            C_SCALP_RANDOM_READY        => C_SCALP_RANDOM_READY)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpAxism2sxDI     => TXAxism2sVectorxD(C_WEST_IF_ID),
            ScalpAxiss2mxDO     => TXAxiss2mVectorxD(C_WEST_IF_ID),
            ScalpPacketxDO      => ScalpPacketEndWestxD,
            ScalpPacketValidxSO => ScalpPacketValidEndxD(C_WEST_IF_ID));

    ScalpAxisToSpTopxI : entity work.scalp_axis_to_sp
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE,
            C_SCALP_RANDOM_READY        => C_SCALP_RANDOM_READY)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpAxism2sxDI     => TXAxism2sVectorxD(C_TOP_IF_ID),
            ScalpAxiss2mxDO     => TXAxiss2mVectorxD(C_TOP_IF_ID),
            ScalpPacketxDO      => ScalpPacketEndTopxD,
            ScalpPacketValidxSO => ScalpPacketValidEndxD(C_TOP_IF_ID));

    ScalpAxisToSpBottomxI : entity work.scalp_axis_to_sp
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE,
            C_SCALP_RANDOM_READY        => C_SCALP_RANDOM_READY)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpAxism2sxDI     => TXAxism2sVectorxD(C_BOTTOM_IF_ID),
            ScalpAxiss2mxDO     => TXAxiss2mVectorxD(C_BOTTOM_IF_ID),
            ScalpPacketxDO      => ScalpPacketEndBottomxD,
            ScalpPacketValidxSO => ScalpPacketValidEndxD(C_BOTTOM_IF_ID));

    ScalpAxisToSpLocalxI : entity work.scalp_axis_to_sp
        generic map (
            C_SCALP_PACKET_PAYLOAD_SIZE => C_SCALP_PACKET_PAYLOAD_SIZE,
            C_SCALP_RANDOM_READY        => C_SCALP_RANDOM_READY)
        port map (
            SysClkxCI           => SysClkxC,
            SysRstxRNAI         => SysRstxRNA,
            ScalpAxism2sxDI     => TXAxism2sVectorxD(C_LOCAL_IF_ID),
            ScalpAxiss2mxDO     => TXAxiss2mVectorxD(C_LOCAL_IF_ID),
            ScalpPacketxDO      => ScalpPacketEndLocalxD,
            ScalpPacketValidxSO => ScalpPacketValidEndxD(C_LOCAL_IF_ID));

    ---------------------------------------------------------------------------
    -- North
    ---------------------------------------------------------------------------
    NorthxB : block is
    begin  -- block NorthxB
        ScalpPacketNorthSelectxAS : ScalpPacketNorthxD <= ScalpPacket0xD when ScalpPacketSelectNorthxD = 0 else
                                                          ScalpPacket1xD when ScalpPacketSelectNorthxD = 1 else
                                                          ScalpPacket2xD when ScalpPacketSelectNorthxD = 2 else
                                                          ScalpPacket3xD when ScalpPacketSelectNorthxD = 3 else
                                                          ScalpPacket4xD when ScalpPacketSelectNorthxD = 4 else
                                                          ScalpPacket5xD when ScalpPacketSelectNorthxD = 5;
        ScalpPacketValidNorthSelectxAS : ScalpPacketValidNorthxS <= ScalpPacketValid0xS when ScalpPacketSelectNorthxD = 0 else
                                                                    ScalpPacketValid1xS when ScalpPacketSelectNorthxD = 1 else
                                                                    ScalpPacketValid2xS when ScalpPacketSelectNorthxD = 2 else
                                                                    ScalpPacketValid3xS when ScalpPacketSelectNorthxD = 3 else
                                                                    ScalpPacketValid4xS when ScalpPacketSelectNorthxD = 4 else
                                                                    ScalpPacketValid5xS when ScalpPacketSelectNorthxD = 5;

        ScalpPacketSendFromNorthxP : process is
        begin  -- process ScalpPacketSendFromNorthxP
            ScalpPacketSelectNorthxD <= 0;

            wait until (SysRstxRNA = '1');
            wait until rising_edge(SysClkxC);
            wait until rising_edge(SysClkxC);

            -- wait until ScalpRdyxD(C_NORTH_IF_ID) = '1';

            ScalpPacketValid0xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid0xS <= '0';

            wait until ScalpRdyxD(C_NORTH_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectNorthxD <= 1;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid1xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid1xS <= '0';

            wait until ScalpRdyxD(C_NORTH_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectNorthxD <= 2;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid2xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid2xS <= '0';

            wait until ScalpRdyxD(C_NORTH_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectNorthxD <= 3;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid3xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid3xS <= '0';

            wait until ScalpRdyxD(C_NORTH_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectNorthxD <= 4;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid4xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid4xS <= '0';

            wait until ScalpRdyxD(C_NORTH_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectNorthxD <= 5;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid5xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid5xS <= '0';

            wait until ScalpRdyxD(C_NORTH_IF_ID) = '1';

            wait;
        end process ScalpPacketSendFromNorthxP;

    end block NorthxB;

    ---------------------------------------------------------------------------
    -- East
    ---------------------------------------------------------------------------
    EastxB : block is
    begin  -- block EastxB
        ScalpPacketEastSelectxAS : ScalpPacketEastxD <= ScalpPacket6xD when ScalpPacketSelectEastxD = 0 else
                                                        ScalpPacket7xD  when ScalpPacketSelectEastxD = 1 else
                                                        ScalpPacket8xD  when ScalpPacketSelectEastxD = 2 else
                                                        ScalpPacket9xD  when ScalpPacketSelectEastxD = 3 else
                                                        ScalpPacket10xD when ScalpPacketSelectEastxD = 4 else
                                                        ScalpPacket11xD when ScalpPacketSelectEastxD = 5;
        ScalpPacketValidEastSelectxAS : ScalpPacketValidEastxS <= ScalpPacketValid6xS when ScalpPacketSelectEastxD = 0 else
                                                                  ScalpPacketValid7xS  when ScalpPacketSelectEastxD = 1 else
                                                                  ScalpPacketValid8xS  when ScalpPacketSelectEastxD = 2 else
                                                                  ScalpPacketValid9xS  when ScalpPacketSelectEastxD = 3 else
                                                                  ScalpPacketValid10xS when ScalpPacketSelectEastxD = 4 else
                                                                  ScalpPacketValid11xS when ScalpPacketSelectEastxD = 5;

        ScalpPacketSendFromEastxP : process is
        begin  -- process ScalpPacketSendFromEastxP
            ScalpPacketSelectEastxD <= 0;

            wait until (SysRstxRNA = '1');
            wait until rising_edge(SysClkxC);
            wait until rising_edge(SysClkxC);

            -- wait until ScalpRdyxD(C_NORTH_IF_ID) = '1';

            ScalpPacketValid6xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid6xS <= '0';

            wait until ScalpRdyxD(C_EAST_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectEastxD <= 1;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid7xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid7xS <= '0';

            wait until ScalpRdyxD(C_EAST_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectEastxD <= 2;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid8xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid8xS <= '0';

            wait until ScalpRdyxD(C_EAST_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectEastxD <= 3;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid9xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid9xS <= '0';

            wait until ScalpRdyxD(C_EAST_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectEastxD <= 4;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid10xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid10xS <= '0';

            wait until ScalpRdyxD(C_EAST_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectEastxD <= 5;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid11xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid11xS <= '0';

            wait until ScalpRdyxD(C_EAST_IF_ID) = '1';

            wait;
        end process ScalpPacketSendFromEastxP;

    end block EastxB;

    -- ---------------------------------------------------------------------------
    -- -- South
    -- ---------------------------------------------------------------------------
    SouthxB : block is
    begin  -- block SouthxB
        ScalpPacketEastSelectxAS : ScalpPacketSouthxD <= ScalpPacket12xD when ScalpPacketSelectSouthxD = 0 else
                                                         ScalpPacket13xD when ScalpPacketSelectSouthxD = 1 else
                                                         ScalpPacket14xD when ScalpPacketSelectSouthxD = 2 else
                                                         ScalpPacket15xD when ScalpPacketSelectSouthxD = 3 else
                                                         ScalpPacket16xD when ScalpPacketSelectSouthxD = 4 else
                                                         ScalpPacket17xD when ScalpPacketSelectSouthxD = 5;
        ScalpPacketValidEastSelectxAS : ScalpPacketValidSouthxS <= ScalpPacketValid12xS when ScalpPacketSelectSouthxD = 0 else
                                                                   ScalpPacketValid13xS when ScalpPacketSelectSouthxD = 1 else
                                                                   ScalpPacketValid14xS when ScalpPacketSelectSouthxD = 2 else
                                                                   ScalpPacketValid15xS when ScalpPacketSelectSouthxD = 3 else
                                                                   ScalpPacketValid16xS when ScalpPacketSelectSouthxD = 4 else
                                                                   ScalpPacketValid17xS when ScalpPacketSelectSouthxD = 5;

        ScalpPacketSendFromSouthxP : process is
        begin  -- process ScalpPacketSendFromSouthxP
            ScalpPacketSelectSouthxD <= 0;

            wait until (SysRstxRNA = '1');
            wait until rising_edge(SysClkxC);
            wait until rising_edge(SysClkxC);

            -- wait until ScalpRdyxD() = '1';

            ScalpPacketValid12xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid12xS <= '0';

            wait until ScalpRdyxD(C_SOUTH_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectSouthxD <= 1;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid13xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid13xS <= '0';

            wait until ScalpRdyxD(C_SOUTH_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectSouthxD <= 2;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid14xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid14xS <= '0';

            wait until ScalpRdyxD(C_SOUTH_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectSouthxD <= 3;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid15xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid15xS <= '0';

            wait until ScalpRdyxD(C_SOUTH_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectSouthxD <= 4;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid16xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid16xS <= '0';

            wait until ScalpRdyxD(C_SOUTH_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectSouthxD <= 5;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid17xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid17xS <= '0';

            wait until ScalpRdyxD(C_SOUTH_IF_ID) = '1';

            wait;
        end process ScalpPacketSendFromSouthxP;

    end block SouthxB;

    -- ---------------------------------------------------------------------------
    -- -- West
    -- ---------------------------------------------------------------------------
    WestxB : block is
    begin  -- block WestxB
        ScalpPacketEastSelectxAS : ScalpPacketWestxD <= ScalpPacket18xD when ScalpPacketSelectWestxD = 0 else
                                                        ScalpPacket19xD when ScalpPacketSelectWestxD = 1 else
                                                        ScalpPacket20xD when ScalpPacketSelectWestxD = 2 else
                                                        ScalpPacket21xD when ScalpPacketSelectWestxD = 3 else
                                                        ScalpPacket22xD when ScalpPacketSelectWestxD = 4 else
                                                        ScalpPacket23xD when ScalpPacketSelectWestxD = 5;
        ScalpPacketValidEastSelectxAS : ScalpPacketValidWestxS <= ScalpPacketValid18xS when ScalpPacketSelectWestxD = 0 else
                                                                  ScalpPacketValid19xS when ScalpPacketSelectWestxD = 1 else
                                                                  ScalpPacketValid20xS when ScalpPacketSelectWestxD = 2 else
                                                                  ScalpPacketValid21xS when ScalpPacketSelectWestxD = 3 else
                                                                  ScalpPacketValid22xS when ScalpPacketSelectWestxD = 4 else
                                                                  ScalpPacketValid23xS when ScalpPacketSelectWestxD = 5;

        ScalpPacketSendFromWestxP : process is
        begin  -- process ScalpPacketSendFromWestxP
            ScalpPacketSelectWestxD <= 0;

            wait until (SysRstxRNA = '1');
            wait until rising_edge(SysClkxC);
            wait until rising_edge(SysClkxC);

            -- wait until ScalpRdyxD() = '1';

            ScalpPacketValid18xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid18xS <= '0';

            wait until ScalpRdyxD(C_WEST_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectWestxD <= 1;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid19xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid19xS <= '0';

            wait until ScalpRdyxD(C_WEST_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectWestxD <= 2;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid20xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid20xS <= '0';

            wait until ScalpRdyxD(C_WEST_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectWestxD <= 3;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid21xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid21xS <= '0';

            wait until ScalpRdyxD(C_WEST_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectWestxD <= 4;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid22xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid22xS <= '0';

            wait until ScalpRdyxD(C_WEST_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectWestxD <= 5;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid23xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid23xS <= '0';

            wait until ScalpRdyxD(C_WEST_IF_ID) = '1';

            wait;
        end process ScalpPacketSendFromWestxP;

    end block WestxB;

    -- ---------------------------------------------------------------------------
    -- -- Top
    -- ---------------------------------------------------------------------------
    TopxB : block is
    begin  -- block TopxB
        ScalpPacketEastSelectxAS : ScalpPacketTopxD <= ScalpPacket24xD when ScalpPacketSelectTopxD = 0 else
                                                       ScalpPacket25xD when ScalpPacketSelectTopxD = 1 else
                                                       ScalpPacket26xD when ScalpPacketSelectTopxD = 2 else
                                                       ScalpPacket27xD when ScalpPacketSelectTopxD = 3 else
                                                       ScalpPacket28xD when ScalpPacketSelectTopxD = 4 else
                                                       ScalpPacket29xD when ScalpPacketSelectTopxD = 5;
        ScalpPacketValidEastSelectxAS : ScalpPacketValidTopxS <= ScalpPacketValid24xS when ScalpPacketSelectTopxD = 0 else
                                                                 ScalpPacketValid25xS when ScalpPacketSelectTopxD = 1 else
                                                                 ScalpPacketValid26xS when ScalpPacketSelectTopxD = 2 else
                                                                 ScalpPacketValid27xS when ScalpPacketSelectTopxD = 3 else
                                                                 ScalpPacketValid28xS when ScalpPacketSelectTopxD = 4 else
                                                                 ScalpPacketValid29xS when ScalpPacketSelectTopxD = 5;

        ScalpPacketSendFromTopxP : process is
        begin  -- process ScalpPacketSendFromTopxP
            ScalpPacketSelectTopxD <= 0;

            wait until (SysRstxRNA = '1');
            wait until rising_edge(SysClkxC);
            wait until rising_edge(SysClkxC);

            -- wait until ScalpRdyxD() = '1';

            ScalpPacketValid24xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid24xS <= '0';

            wait until ScalpRdyxD(C_TOP_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectTopxD <= 1;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid25xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid25xS <= '0';

            wait until ScalpRdyxD(C_TOP_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectTopxD <= 2;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid26xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid26xS <= '0';

            wait until ScalpRdyxD(C_TOP_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectTopxD <= 3;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid27xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid27xS <= '0';

            wait until ScalpRdyxD(C_TOP_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectTopxD <= 4;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid28xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid28xS <= '0';

            wait until ScalpRdyxD(C_TOP_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectTopxD <= 5;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid29xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid29xS <= '0';

            wait until ScalpRdyxD(C_TOP_IF_ID) = '1';

            wait;
        end process ScalpPacketSendFromTopxP;

    end block TopxB;

    -- ---------------------------------------------------------------------------
    -- -- Bottom
    -- ---------------------------------------------------------------------------
    BottomxB : block is
    begin  -- block BottomxB
        ScalpPacketEastSelectxAS : ScalpPacketBottomxD <= ScalpPacket30xD when ScalpPacketSelectBottomxD = 0 else
                                                          ScalpPacket31xD when ScalpPacketSelectBottomxD = 1 else
                                                          ScalpPacket32xD when ScalpPacketSelectBottomxD = 2 else
                                                          ScalpPacket33xD when ScalpPacketSelectBottomxD = 3 else
                                                          ScalpPacket34xD when ScalpPacketSelectBottomxD = 4 else
                                                          ScalpPacket35xD when ScalpPacketSelectBottomxD = 5;
        ScalpPacketValidEastSelectxAS : ScalpPacketValidBottomxS <= ScalpPacketValid30xS when ScalpPacketSelectBottomxD = 0 else
                                                                    ScalpPacketValid31xS when ScalpPacketSelectBottomxD = 1 else
                                                                    ScalpPacketValid32xS when ScalpPacketSelectBottomxD = 2 else
                                                                    ScalpPacketValid33xS when ScalpPacketSelectBottomxD = 3 else
                                                                    ScalpPacketValid34xS when ScalpPacketSelectBottomxD = 4 else
                                                                    ScalpPacketValid35xS when ScalpPacketSelectBottomxD = 5;

        ScalpPacketSendFromBottomxP : process is
        begin  -- process ScalpPacketSendFromBottomxP
            ScalpPacketSelectBottomxD <= 0;

            wait until (SysRstxRNA = '1');
            wait until rising_edge(SysClkxC);
            wait until rising_edge(SysClkxC);

            -- wait until ScalpRdyxD() = '1';

            ScalpPacketValid30xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid30xS <= '0';

            wait until ScalpRdyxD(C_BOTTOM_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectBottomxD <= 1;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid31xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid31xS <= '0';

            wait until ScalpRdyxD(C_BOTTOM_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectBottomxD <= 2;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid32xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid32xS <= '0';

            wait until ScalpRdyxD(C_BOTTOM_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectBottomxD <= 3;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid33xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid33xS <= '0';

            wait until ScalpRdyxD(C_BOTTOM_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectBottomxD <= 4;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid34xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid34xS <= '0';

            wait until ScalpRdyxD(C_BOTTOM_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectBottomxD <= 5;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid35xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid35xS <= '0';

            wait until ScalpRdyxD(C_BOTTOM_IF_ID) = '1';

            wait;
        end process ScalpPacketSendFromBottomxP;

    end block BottomxB;

    -- ---------------------------------------------------------------------------
    -- -- Local
    -- ---------------------------------------------------------------------------
    LocalxB : block is
    begin  -- block LocalxB
        ScalpPacketEastSelectxAS : ScalpPacketLocalxD <= ScalpPacket36xD when ScalpPacketSelectLocalxD = 0 else
                                                         ScalpPacket37xD when ScalpPacketSelectLocalxD = 1 else
                                                         ScalpPacket38xD when ScalpPacketSelectLocalxD = 2 else
                                                         ScalpPacket39xD when ScalpPacketSelectLocalxD = 3 else
                                                         ScalpPacket40xD when ScalpPacketSelectLocalxD = 4 else
                                                         ScalpPacket41xD when ScalpPacketSelectLocalxD = 5;
        ScalpPacketValidEastSelectxAS : ScalpPacketValidLocalxS <= ScalpPacketValid36xS when ScalpPacketSelectLocalxD = 0 else
                                                                   ScalpPacketValid37xS when ScalpPacketSelectLocalxD = 1 else
                                                                   ScalpPacketValid38xS when ScalpPacketSelectLocalxD = 2 else
                                                                   ScalpPacketValid39xS when ScalpPacketSelectLocalxD = 3 else
                                                                   ScalpPacketValid40xS when ScalpPacketSelectLocalxD = 4 else
                                                                   ScalpPacketValid41xS when ScalpPacketSelectLocalxD = 5;

        ScalpPacketSendFromLocalxP : process is
        begin  -- process ScalpPacketSendFromLocalxP
            ScalpPacketSelectLocalxD <= 0;

            wait until (SysRstxRNA = '1');
            wait until rising_edge(SysClkxC);
            wait until rising_edge(SysClkxC);

            -- wait until ScalpRdyxD() = '1';

            ScalpPacketValid36xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid36xS <= '0';

            wait until ScalpRdyxD(C_LOCAL_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectLocalxD <= 1;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid37xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid37xS <= '0';

            wait until ScalpRdyxD(C_LOCAL_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectLocalxD <= 2;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid38xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid38xS <= '0';

            wait until ScalpRdyxD(C_LOCAL_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectLocalxD <= 3;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid39xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid39xS <= '0';

            wait until ScalpRdyxD(C_LOCAL_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectLocalxD <= 4;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid40xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid40xS <= '0';

            wait until ScalpRdyxD(C_LOCAL_IF_ID) = '1';

            -------------------------------------------------------------------

            ScalpPacketSelectLocalxD <= 5;

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid41xS <= '1';

            for i in 0 to 0 loop
                wait until rising_edge(SysClkxC);
            end loop;  -- i

            ScalpPacketValid41xS <= '0';

            wait until ScalpRdyxD(C_LOCAL_IF_ID) = '1';

            wait;
        end process ScalpPacketSendFromLocalxP;

    end block LocalxB;

    ScalpNorthEndxP : process is
    begin  -- process ScalpNorthEndxP
        ScalpNorthEndCounterxD := 0;

        wait until (SysRstxRNA = '1');
        wait until rising_edge(SysClkxC);
        wait until rising_edge(SysClkxC);

        for i in 0 to 5 loop
            wait until ScalpPacketValidEndxD(C_NORTH_IF_ID) = '1';
            ScalpNorthEndCounterxD := ScalpNorthEndCounterxD + 1;
        end loop;  -- i

        wait;
    end process ScalpNorthEndxP;

    ScalpEastEndxP : process is
    begin  -- process ScalpEastEndxP
        ScalpEastEndCounterxD := 0;

        wait until (SysRstxRNA = '1');
        wait until rising_edge(SysClkxC);
        wait until rising_edge(SysClkxC);

        for i in 0 to 5 loop
            wait until ScalpPacketValidEndxD(C_EAST_IF_ID) = '1';
            ScalpEastEndCounterxD := ScalpEastEndCounterxD + 1;
        end loop;  -- i

        wait;
    end process ScalpEastEndxP;

    ScalpSouthEndxP : process is
    begin  -- process ScalpSouthEndxP
        ScalpSouthEndCounterxD := 0;

        wait until (SysRstxRNA = '1');
        wait until rising_edge(SysClkxC);
        wait until rising_edge(SysClkxC);

        for i in 0 to 5 loop
            wait until ScalpPacketValidEndxD(C_SOUTH_IF_ID) = '1';
            ScalpSouthEndCounterxD := ScalpSouthEndCounterxD + 1;
        end loop;  -- i

        wait;
    end process ScalpSouthEndxP;

    ScalpWestEndxP : process is
    begin  -- process ScalpWestEndxP
        ScalpWestEndCounterxD := 0;

        wait until (SysRstxRNA = '1');
        wait until rising_edge(SysClkxC);
        wait until rising_edge(SysClkxC);

        for i in 0 to 5 loop
            wait until ScalpPacketValidEndxD(C_WEST_IF_ID) = '1';
            ScalpWestEndCounterxD := ScalpWestEndCounterxD + 1;
        end loop;  -- i

        wait;
    end process ScalpWestEndxP;

    ScalpTopEndxP : process is
    begin  -- process ScalpTopEndxP
        ScalpTopEndCounterxD := 0;

        wait until (SysRstxRNA = '1');
        wait until rising_edge(SysClkxC);
        wait until rising_edge(SysClkxC);

        for i in 0 to 5 loop
            wait until ScalpPacketValidEndxD(C_TOP_IF_ID) = '1';
            ScalpTopEndCounterxD := ScalpTopEndCounterxD + 1;
        end loop;  -- i

        wait;
    end process ScalpTopEndxP;

    ScalpBottomEndxP : process is
    begin  -- process ScalpBottomEndxP
        ScalpBottomEndCounterxD := 0;

        wait until (SysRstxRNA = '1');
        wait until rising_edge(SysClkxC);
        wait until rising_edge(SysClkxC);

        for i in 0 to 5 loop
            wait until ScalpPacketValidEndxD(C_BOTTOM_IF_ID) = '1';
            ScalpBottomEndCounterxD := ScalpBottomEndCounterxD + 1;
        end loop;  -- i

        wait;
    end process ScalpBottomEndxP;

    ScalpLocalEndxP : process is
    begin  -- process ScalpLocalEndxP
        ScalpLocalEndCounterxD := 0;

        wait until (SysRstxRNA = '1');
        wait until rising_edge(SysClkxC);
        wait until rising_edge(SysClkxC);

        for i in 0 to 5 loop
            wait until ScalpPacketValidEndxD(C_LOCAL_IF_ID) = '1';
            ScalpLocalEndCounterxD := ScalpLocalEndCounterxD + 1;
        end loop;  -- i

        wait;
    end process ScalpLocalEndxP;

    TestbenchxP : process is
    begin  -- process TestbenchxP
        wait until (SysRstxRNA = '1');
        wait until rising_edge(SysClkxC);
        wait until rising_edge(SysClkxC);

        L0xL : loop
            wait until rising_edge(SysClkxC);

            -- North
            -- exit L0xL when (ScalpEastEndCounterxD = 1 and
            --                 ScalpSouthEndCounterxD = 1 and
            --                 ScalpWestEndCounterxD = 1 and
            --                 ScalpTopEndCounterxD = 1 and
            --                 ScalpBottomEndCounterxD = 1 and
            --                 ScalpLocalEndCounterxD = 1);

            exit L0xL when (ScalpNorthEndCounterxD = 6 and
                            ScalpEastEndCounterxD = 6 and
                            ScalpSouthEndCounterxD = 6 and
                            ScalpWestEndCounterxD = 6 and
                            ScalpTopEndCounterxD = 6 and
                            ScalpBottomEndCounterxD = 6 and
                            ScalpLocalEndCounterxD = 6);
        end loop L0xL;

        for i in 0 to 99 loop
            wait until rising_edge(SysClkxC);
        end loop;  -- i

        EndSimxS <= true;
    end process TestbenchxP;

end architecture testbench;
